const fs = require('fs');
const path = require('path');

// Spécifiez le dossier où se trouvent les fichiers JSON
const directoryPath = './'; // Remplacez par le chemin de votre dossier

// Fonction pour parcourir le dossier de manière récursive
function processDirectory(directory) {
    fs.readdir(directory, (err, files) => {
        if (err) {
            console.log(`Erreur de lecture du dossier ${directory}:`, err);
            return;
        }

        // Traiter chaque fichier ou sous-dossier
        files.forEach(file => {
            const filePath = path.join(directory, file);

            // Vérifier si c'est un fichier ou un sous-dossier
            fs.stat(filePath, (err, stats) => {
                if (err) {
                    console.log(`Erreur de stat du fichier ${filePath}:`, err);
                    return;
                }

                if (stats.isDirectory()) {
                    // Si c'est un sous-dossier, appeler la fonction récursive
                    processDirectory(filePath);
                } else if (stats.isFile() && path.extname(file) === '.json') {
                    // Si c'est un fichier JSON, le traiter
                    updateJsonFile(filePath);
                }
            });
        });
    });
}

// Fonction pour modifier le fichier JSON
function updateJsonFile(filePath) {
    // Lire le fichier JSON
    fs.readFile(filePath, 'utf8', (err, data) => {
        if (err) {
            console.log(`Erreur de lecture du fichier ${filePath}:`, err);
            return;
        }

        try {
            // Analyser le contenu du fichier JSON
            const jsonData = JSON.parse(data);

            // Vérifier si la clé "rewards" existe et la modifier
            if (jsonData.rewards) {
                jsonData.rewards = {
                    "function": "neoterra:map/expand_border"
                };
            }

            if (jsonData.display) {
                delete jsonData.display
            }
            
            // Sauvegarder le fichier JSON modifié
            fs.writeFile(filePath, JSON.stringify(jsonData, null, 2), 'utf8', (err) => {
                if (err) {
                    console.log(`Erreur de sauvegarde du fichier ${filePath}:`, err);
                } else {
                    console.log(`Fichier ${filePath} mis à jour avec succès.`);
                }
            });

        } catch (err) {
            console.log(`Erreur de parsing JSON dans le fichier ${filePath}:`, err);
        }
    });
}

// Lancer le traitement sur le dossier de départ
processDirectory(directoryPath);
